import React, { Component, Fragment } from 'react';
import { queryConfig } from '../services';
import { getInfo } from '@/highOrderComponent/Service';
import { message, Button } from 'antd';
import Shell from '@/baseComponent/Shell';
import ReactToPrint from 'react-to-print';
import ButtonDiy from '@/baseComponent/ButtonDiy';
import router from 'umi/router';
import styles from '../index.less';
import DetailDom from './DetailDom';
import { imageStyleAll, A4Width, A4Height, getCLodopFuncJS } from './config';
import RenderAuthorized from '@/components/Authorized';
import { getAuthority } from '@/utils/authority';

const Authorized = RenderAuthorized(getAuthority());
const { check } = Authorized;

import { ModalInfo } from '@/baseComponent/Modal';
import replace from '../../../../../config/zydxg/routes/studentAffairs/replace';

export default class ViewPrint extends Component {
  constructor(props) {
    super(props);
    this.state = {
      configAll: null,
      viewData: null,
      loading: true,
      printIndex: 0,
      showWindowPrint: false,
    };
    this.getConfigInfo = queryConfig.bind(this);
  }

  getViewData = () => {
    const { selectedRows } = this.props;
    const ids = selectedRows.map((x) => x.id);
    this.getConfigInfo().then((x) => {
      if (x && x.queryUrl) {
        getInfo(
          {
            ids: ids.join(','),
          },
          x.queryUrl,
        ).then((viewData) => {
          if (!viewData || !viewData.length) {
            message.warning('未查询到可打印的奖状数据');
            console.error(`${x.queryUrl}接口报错或者没有返回数据`);
            return false;
          }
          // let i = 0;
          for (const item of viewData) {
            //  item.name = ['黎处', '王昊楠', '古力娜扎', '古丽尼帕尔·阿布都黑利力'][i] || '钟是志';
            //  i++;
            for (let z in item) {
              if (item[z] === null || item[z] === 'null') {
                item[z] = '';
              }
            }
          }
          this.setState({
            viewData,
          });
        });
      }
    });
  };

  componentDidMount() {
    this.getViewData();
    getCLodopFuncJS().then((response) => {
      window.On_CLodop_Opened = function(){
        console.log('On_CLodop_Opened');
        window.On_CLodop_Opened = null;
      };
      if (response) {
        this.setState({
          loading: false,
        });
      }
    });

  }

  detailDom = (data) => {
    const {
      configAll: { config },
    } = this.state;
    const res = [];
    for (const item of config) {
      res.push(
        DetailDom({
          config: item,
          data: data[item.fieldCode],
        }),
      );
    }
    return res;
  };

  printOne = () => {
    const { printIndex, configAll, viewData } = this.state;
    const { wide, high } = configAll;
    let LODOPObj = window.LODOP;
    let strHTML = document.getElementById(`printDomId_${printIndex}`).innerHTML;
    strHTML = strHTML.replace(
      'break-after: page;',
      'page-break-after: always;',
    );
    strHTML = `<!DOCTYPE html><html lang="en"><head><meta charset="UTF-8"></head><body>${strHTML}</body></html>`;
    // console.log(strHTML);
    LODOPObj.PRINT_INIT(`printDomId_${printIndex}`);
    //  window.LODOP.PRINT_INITA(1, 1, 770, 660, '测试预览功能');
    LODOPObj.ADD_PRINT_HTM(0, 0, `${wide + 0.1}cm`, `${high + 0.1}cm`, strHTML); // 打印的宽高和 html
    LODOPObj.SET_PRINT_PAGESIZE(2, 0, 0); // 纵向打印
    LODOPObj.PREVIEW();
    //LODOPObj.PRINT();
    // LODOPObj.PRINT_SETUP();
  };

  printOneByOne = () => {
    // 按队列打印
    const { configAll, viewData, printIndex } = this.state;
    if (viewData && viewData.length) {
      message.info(`正在打印第${printIndex + 1}张奖状`);
      this.printOne();
      const { length } = viewData;
      let LODOPObj = window.LODOP;
      LODOPObj.On_Return_Remain = true;
      LODOPObj.On_Return = (TaskId, Value) => {
        console.log(TaskId, Value === 1 || Value === '1' ? '已发出实际打印命令！' : '放弃打印！');
        this.setState({
            printIndex: this.state.printIndex + 1,
          }, () => {
            if (this.state.printIndex < length) {
              message.info(`正在打印第${this.state.printIndex + 1}张奖状`);
              this.printOne();
            } else {
              this.setState({
                loading: false,
              });
            }
          },
        );
      };
    } else {
      console.error('暂无数据无法打印');
    }
  };

  printByLodop = () => {
    if (!window.LODOP || !window.LODOP.PRINT_INIT) {
      console.error('打印服务未启动');
      ModalInfo('打印服务未启动');
      return false;
    }
    this.setState(
      {
        showWindowPrint: true,
        printIndex: 0,
      },
      () => {
        this.printOneByOne();
      },
    );
  };

  render() {
    const { configAll, viewData, showWindowPrint, loading, printBg } = this.state;
    if (!viewData) {
      return null;
    }
    if (!configAll.backgroundUrl) {
      console.error('没有设置模版图片无法使用');
      return null;
    }
    const { hasPrintBackground, backgroundUrl, wide, high } = configAll;
    let imageStyle = {
      height: `${high}cm` || A4Height,
      width: `${wide}cm` || A4Width,
    };
    return (
      <Fragment>
        <Shell styleShell={{ marginTop: '0', marginBottom: '20px' }}>
          <div style={{ height: '54px', padding: '12px 0 12px 12px' }}>
            <ButtonDiy
              name={'打印设备选择'}
              handleClick={() => {
                window.LODOP.SELECT_PRINTER();
              }}
              loading={loading}
            />
            <ButtonDiy
              name={'打印背景图'}
              handleClick={() => {
                this.setState({
                  printBg: true,
                }, () => {
                  this.printByLodop();
                });
              }}
              loading={loading}
            />
            <ButtonDiy
              name={'打印'}
              handleClick={this.setState({
                printBg: false,
              }, () => {
                this.printByLodop();
              })}
              loading={loading}
            />
            <ButtonDiy
              name={'返回'}
              handleClick={() => {
                router.goBack();
              }}
            />
          </div>
        </Shell>

        {/** 预览的dom */}
        {viewData && viewData.length ? (
          <div>
            {viewData.map((info, index) => {
              return (
                <div
                  className={styles.outSideDivPrint}
                  key={index + 'divKey'}
                  style={{
                    ...imageStyle,
                  }}>
                  <img
                    src={backgroundUrl}
                    draggable={false}
                    className={styles.bgimagePrint}
                    alt={'背景图'}
                    style={imageStyleAll}
                  />
                  {this.detailDom(info)}
                </div>
              );
            })}
          </div>
        ) : null}

        {/**  打印的dom */}
        {viewData && viewData.length ? (
          <div
            ref={(node) => (this.content = node)}
            style={{
              display: showWindowPrint && false ? 'block' : 'none',
            }}>
            {viewData.map((info, index) => {
              return (
                <div
                  key={`${index}divKey`}
                  id={`printDomId_${index}`}
                  style={{}}>
                  <div
                    style={{
                      position: 'relative',
                      width: 'auto',
                      pageBreakAfter: 'always',
                      ...imageStyle,
                    }}>
                    {hasPrintBackground || printBg ? (
                      <img
                        src={backgroundUrl}
                        draggable={false}
                        alt={'背景图'}
                        style={{
                          zIndex: 1,
                          ...imageStyleAll,
                        }}
                      />
                    ) : null}
                    {this.detailDom(info)}
                  </div>
                </div>
              );
            })}
          </div>
        ) : null}
      </Fragment>
    );
  }
}
